@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.100';
+our $VERSION = '0.101';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Fri Jul 13 14:43:18 2018 GMT
+# on Fri Jul 20 13:07:17 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1747,7 +1747,7 @@ __PACKAGE__->status( add => 25276, iridium => '+', 'Iridium 60', '' );
 __PACKAGE__->status( add => 25285, iridium => 'S', 'Iridium 62', '' );
 __PACKAGE__->status( add => 25286, iridium => '-', 'Iridium 63', 'Tumbling' );
 __PACKAGE__->status( add => 25287, iridium => 'S', 'Iridium 64', '' );
-__PACKAGE__->status( add => 25288, iridium => '-', 'Iridium 65', 'Tumbling' );
+__PACKAGE__->status( add => 25288, iridium => 'D', 'Iridium 65', 'Decayed 2018-07-19' );
 __PACKAGE__->status( add => 25289, iridium => 'S', 'Iridium 66', '' );
 __PACKAGE__->status( add => 25290, iridium => 'D', 'Iridium 67', 'Decayed 2018-07-02' );
 __PACKAGE__->status( add => 25291, iridium => 'D', 'Iridium 68', 'Decayed 2018-06-06' );
@@ -1761,8 +1761,8 @@ __PACKAGE__->status( add => 25346, iridium => 'D', 'Iridium 75', 'Decayed 2018-0
 __PACKAGE__->status( add => 25431, iridium => 'D', 'Iridium 3', 'Decayed 2018-02-08' );
 __PACKAGE__->status( add => 25432, iridium => 'S', 'Iridium 76', '' );
 __PACKAGE__->status( add => 25467, iridium => '-', 'Iridium 82', 'Tumbling' );
-__PACKAGE__->status( add => 25468, iridium => '-', 'Iridium 81', 'Tumbling' );
-__PACKAGE__->status( add => 25469, iridium => 'S', 'Iridium 80', '' );
+__PACKAGE__->status( add => 25468, iridium => 'D', 'Iridium 81', 'Decayed 2018-07-17' );
+__PACKAGE__->status( add => 25469, iridium => '-', 'Iridium 80', 'Tumbling' );
 __PACKAGE__->status( add => 25470, iridium => 'D', 'Iridium 79', 'Decayed 2000-11-29' );
 __PACKAGE__->status( add => 25471, iridium => 'D', 'Iridium 77', 'Decayed 2017-09-22' );
 __PACKAGE__->status( add => 25527, iridium => '-', 'Iridium 2', 'Tumbling' );
@@ -1784,9 +1784,9 @@ __PACKAGE__->status( add => 27451, iridium => 'S', 'Iridium 98', '' );
 
 # Summary:
 # Operational [+]: 17
-#       Spare [S]: 17
-#    Tumbling [-]: 38
-#     Decayed [D]: 25
+#       Spare [S]: 16
+#    Tumbling [-]: 37
+#     Decayed [D]: 27
 
 1;
 
